From 998cd9baa8edbbc0a02509728c7ff21ddaaaad51 Mon Sep 17 00:00:00 2001
From: Alfred Wingate <parona@protonmail.com>
Date: Mon, 20 Nov 2023 23:18:56 +0200
Subject: [PATCH] Add an option for qtdbus support

Signed-off-by: Alfred Wingate <parona@protonmail.com>
--- a/ac/qt5.m4
+++ b/ac/qt5.m4
@@ -103,11 +103,13 @@ check_qt5() {
       return
     fi
 
-    if test x"$MINGW" != x1 && ! echo "$host" | grep -q -i apple ; then
-      PKG_CHECK_EXISTS([Qt5DBus],[dbus_found=yes],[dbus_found=no])
-      if test x"$dbus_found" = xyes; then
-        with_qt_pkg_config_modules="$with_qt_pkg_config_modules,Qt5DBus"
-        AC_DEFINE(HAVE_QTDBUS, 1, [Define if QtDBus is present])
+    if test x"$enable_dbus" = xyes; then
+      if test x"$MINGW" != x1 && ! echo "$host" | grep -q -i apple ; then
+        PKG_CHECK_EXISTS([Qt5DBus],[dbus_found=yes],[dbus_found=no])
+        if test x"$dbus_found" = xyes; then
+          with_qt_pkg_config_modules="$with_qt_pkg_config_modules,Qt5DBus"
+          AC_DEFINE(HAVE_QTDBUS, 1, [Define if QtDBus is present])
+        fi
       fi
     fi
 
@@ -254,6 +256,11 @@ AC_ARG_WITH([qt_pkg_config_modules],
 AC_ARG_WITH([qt_pkg_config],
   AS_HELP_STRING([--without-qt-pkg-config],[do not use pkg-config for detecting Qt 5; instead rely on QT_CFLAGS/QT_LIBS being set correctly already]),
   [ with_qt_pkg_config=${withval} ], [ with_qt_pkg_config=yes ])
+AC_ARG_ENABLE([dbus],
+  AC_HELP_STRING([--enable-dbus],[enable/disable qtdbus/dbus from being included in build (yes)]),
+  [],[enable_dbus=yes])
+
+
 
 have_qt5=no
 
--- a/ac/qt6.m4
+++ b/ac/qt6.m4
@@ -96,9 +96,12 @@ EOT
     if test $result2 != 0; then
       continue
     fi
-    if test $qt_module = dbus; then
-      qmake_qt_ui="$qmake_qt_ui dbus"
-      AC_DEFINE(HAVE_QTDBUS, 1, [Define if QtDBus is present])
+    if test x"$enable_dbus" = xyes; then
+      PKG_CHECK_EXISTS([Qt6DBus],[dbus_found=yes],[dbus_found=no])
+      if test x"$dbus_found" = xyes; then
+        qmake_qt_ui="$qmake_qt_ui dbus"
+        AC_DEFINE(HAVE_QTDBUS, 1, [Define if QtDBus is present])
+      fi
     fi
     if test $qt_module = multimedia; then
       qmake_qt_ui="$qmake_qt_ui multimedia"
@@ -272,6 +275,9 @@ AC_ARG_ENABLE([gui],
 AC_ARG_ENABLE([qt6],
   AS_HELP_STRING([--enable-qt6],[compile with Qt 6 (yes)]),
   [],[enable_qt6=yes])
+AC_ARG_ENABLE([dbus],
+  AC_HELP_STRING([--enable-dbus],[enable/disable qtdbus/dbus from being included in build (yes)]),
+  [],[enable_dbus=yes])
 
 have_qt6=no
 
-- 
2.43.0

